|Python version| |Build Status| |Code Health| |Documentation|

Cosmic Ray: mutation testing for Python
=======================================

*"Four human beings -- changed by space-born cosmic rays into something
more than merely human."* *— The Fantastic Four*

Cosmic Ray is a mutation testing tool for Python 3.

Cosmic Ray is still learning how to walk!
-----------------------------------------

At this time Cosmic Ray is young and incomplete. It doesn't support all
of the mutations it should, its output format is crude, it only supports
some forms of test discovery, it may fall over on exotic
modules...\ `the list goes on and
on <https://github.com/sixty-north/cosmic-ray/issues>`_. Still, for the
adventurous it *does* work. Hopefully things will improve fairly
rapidly.

And, of course, patches and ideas are welcome.

|full_documentation|_

.. |Python version| image:: https://img.shields.io/badge/Python_version-3.4+-blue.svg
   :target: https://www.python.org/
.. |Build Status| image:: https://travis-ci.org/sixty-north/cosmic-ray.png?branch=master
   :target: https://travis-ci.org/sixty-north/cosmic-ray
.. |Code Health| image:: https://landscape.io/github/sixty-north/cosmic-ray/master/landscape.svg?style=flat
   :target: https://landscape.io/github/sixty-north/cosmic-ray/master
.. |Documentation| image:: https://readthedocs.org/projects/cosmic-ray/badge/?version=latest
   :target: http://cosmic-ray.readthedocs.org/en/latest/
.. |full_documentation| replace:: **Read the full documentation at readthedocs.**
.. _full_documentation: http://cosmic-ray.readthedocs.org/en/latest/
